@@ -78,8 +78,10 @@ GVPart::GVPart(QWidget* parentWidget, QObject* parent, const QVariantList& /*arg
 
     QAction * action = new QAction(actionCollection());
     action->setText(i18nc("@action", "Properties"));
+    action->setShortcut(QKeySequence(Qt::ALT + Qt::Key_Return));
     connect(action, &QAction::triggered, this, &GVPart::showProperties);
-    actionCollection()->addAction("file_show_properties", action);
+    actionCollection()->addAction(QStringLiteral("file_show_properties"), action);
+
 
     KStandardAction::saveAs(this, SLOT(saveAs()), actionCollection());
 
